:orphan:

######################
GeoComPy documentation
######################

********
GeoComPy
********

.. toctree::
   :maxdepth: 2

   overview
   introduction
   connections
   changelog

*****************
API documentation
*****************

.. toctree::
   :maxdepth: 3

   api/index
   api/data
   api/communication
   api/gsi/index
   api/gsi/dna/index
   api/geo/index
